import axiosInstance from "./axiosInstance";

interface LoginResponse {
    isLogged: boolean;
    nextAction(): void;
}

class FailedLoginError extends Error{
    code: number;
    constructor (msg: string, code: number){
        super(msg);
        this.code = code;
        Object.setPrototypeOf(this, FailedLoginError.prototype)
    }
}

// type ApiToken = string;

/**
 * 
 * @param user the name of user logging in (if it's a customer, then it's his email)
 * @param password  the password of the user
 * @returns 
 */
export default async function login(user: string, password: string): Promise<ApiToken>{
    // const user = useContext(userContext);
    const res =  await axiosInstance.get("/login", { params: { user, password } });
    if (res.data.login.result == "ERROR") {
        const errCode: number = res.data.login.errorCode;
        const errMsg: string = res.data.login.message;
        throw new FailedLoginError(errMsg, errCode);
    }
    return res.data.login.customerProperties.token;
}

export { FailedLoginError };