import isTokenValid from "@api/isTokenValid";
import ErrorPage from "@components/ErrorPage";
import React, { useEffect } from "react";
import { useNavigate, useSearchParams } from "react-router-dom";

type AuthProps = {
    children: React.ReactNode,
}
export default function AuthComponent({ children }: AuthProps) {
    const navigate = useNavigate();

    useEffect(() => {
        // navigate needs to be wrapped in a useEffect so that it gets executed after the component is mounted. Otherwise it doesn't redirect
        (async () => {
            const token: ApiToken = window.localStorage.getItem("token");
            const isLogged: boolean = token != null && await isTokenValid(token);
            if (!isLogged)
                navigate("/login", { replace: true });
        })()
    }, [])

    // by default return the children, the effect will check if the user needs to be redirected
    return <>{children}</>;
}